debugpy: Implementation of the Debug Adapter Protocol for Python
================================================================

Description
-----------

Implementation of the Debug Adapter Protocol for Python

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/debugpy/

